@@ -382,12 +382,33 @@ Client::check_permission(DBus::Connection& conn, DBus::Message& msg,
 			 const MetaSnapper& meta_snapper) const
 {
     unsigned long uid = conn.get_unix_userid(msg);
+
+    // Check if the uid of the dbus-user is root.
     if (uid == 0)
 	return;
 
-    if (find(meta_snapper.uids.begin(), meta_snapper.uids.end(), uid) != meta_snapper.uids.end())
+    // Check if the uid of the dbus-user is included in the allowed uids.
+    if (contains(meta_snapper.uids, uid))
 	return;
 
+    string username;
+    gid_t gid;
+
+    if (get_uid_username_gid(uid, username, gid))
+    {
+	// Check if the primary gid of the dbus-user is included in the allowed gids.
+	if (contains(meta_snapper.gids, gid))
+	    return;
+
+	vector<gid_t> gids = getgrouplist(username.c_str(), gid);
+
+	// Check if any (primary or secondary) gid of the dbus-user is included in the allowed
+	// gids.
+	for (vector<gid_t>::const_iterator it = gids.begin(); it != gids.end(); ++it)
+	    if (contains(meta_snapper.gids, *it))
+		return;
+    }
+
     throw Permissions();
 }
 
@@ -1346,25 +1367,8 @@ Client::debug(DBus::Connection& conn, DBus::Message& msg) const
     }
 
     hoho << "compile options:";
-    hoho << "  VERSION " VERSION;
-#ifdef ENABLE_BTRFS
-    hoho << "  ENABLE_BTRFS";
-#endif
-#ifdef ENABLE_LVM
-    hoho << "  ENABLE_LVM";
-#endif
-#ifdef ENABLE_EXT4
-    hoho << "  ENABLE_EXT4";
-#endif
-#ifdef ENABLE_XATTRS
-    hoho << "  ENABLE_XATTRS";
-#endif
-#ifdef ENABLE_ROLLBACK
-    hoho << "  ENABLE_ROLLBACK";
-#endif
-#ifdef HAVE_LIBBTRFS
-    hoho << "  HAVE_LIBBTRFS";
-#endif
+    hoho << "    version " + string(Snapper::compileVersion());
+    hoho << "    flags " + string(Snapper::compileFlags());
 
     hoho.close_array();
 
