@@ -34,6 +34,11 @@
 #include <libmount/libmount.h>
 #endif
 #ifdef HAVE_LIBBTRFS
+#ifdef HAVE_BTRFS_VERSION_H
+#include <btrfs/version.h>
+#else
+#define BTRFS_LIB_VERSION (100)
+#endif
 #include <btrfs/ioctl.h>
 #include <btrfs/send.h>
 #include <btrfs/send-stream.h>
@@ -69,11 +74,30 @@ namespace snapper
 
 
     Btrfs::Btrfs(const string& subvolume)
-	: Filesystem(subvolume)
+	: Filesystem(subvolume), qgroup(no_qgroup)
     {
     }
 
 
+    void
+    Btrfs::evalConfigInfo(const ConfigInfo& config_info)
+    {
+	string qgroup_str;
+	if (config_info.getValue("QGROUP", qgroup_str) && !qgroup_str.empty())
+	{
+	    try
+	    {
+		qgroup = make_qgroup(qgroup_str);
+	    }
+	    catch (const runtime_error& e)
+	    {
+		y2err("failed to parse qgroup '" << qgroup_str << "'");
+		throw InvalidConfigException();
+	    }
+	}
+    }
+
+
     void
     Btrfs::createConfig(bool add_fstab) const
     {
@@ -232,7 +256,7 @@ namespace snapper
 
 	    try
 	    {
-		create_snapshot(subvolume_dir.fd(), info_dir.fd(), "snapshot", read_only);
+		create_snapshot(subvolume_dir.fd(), info_dir.fd(), "snapshot", read_only, qgroup);
 	    }
 	    catch (const runtime_error& e)
 	    {
@@ -247,7 +271,7 @@ namespace snapper
 
 	    try
 	    {
-		create_snapshot(snapshot_dir.fd(), info_dir.fd(), "snapshot", read_only);
+		create_snapshot(snapshot_dir.fd(), info_dir.fd(), "snapshot", read_only, qgroup);
 	    }
 	    catch (const runtime_error& e)
 	    {
@@ -284,7 +308,7 @@ namespace snapper
 
 	try
 	{
-	    create_snapshot(tmp_mount_dir.fd(), info_dir.fd(), "snapshot", read_only);
+	    create_snapshot(tmp_mount_dir.fd(), info_dir.fd(), "snapshot", read_only, qgroup);
 	}
 	catch (const runtime_error& e)
 	{
@@ -1123,7 +1147,13 @@ namespace snapper
 	    boost::this_thread::interruption_point();
 
 	     // remove the fourth parameter for older versions of libbtrfs
-	    int r = btrfs_read_and_process_send_stream(fd, &send_ops, &*this, 0);
+	    int r;
+
+#if BTRFS_LIB_VERSION < 101
+	    r = btrfs_read_and_process_send_stream(fd, &send_ops, &*this, 0);
+#else
+	    r = btrfs_read_and_process_send_stream(fd, &send_ops, &*this, 0, 1);
+#endif
 
 	    if (r < 0)
 	    {
