@@ -25,6 +25,7 @@
 
 
 #include "snapper/Filesystem.h"
+#include "snapper/BtrfsUtils.h"
 
 
 namespace snapper
@@ -38,6 +39,8 @@ namespace snapper
 
 	Btrfs(const string& subvolume);
 
+	virtual void evalConfigInfo(const ConfigInfo& config_info);
+
 	virtual string fstype() const { return "btrfs"; }
 
 	virtual void createConfig(bool add_fstab) const;
@@ -68,6 +71,8 @@ namespace snapper
 
     private:
 
+	qgroup_t qgroup;
+
 	void addToFstab() const;
 	void removeFromFstab() const;
 
