@@ -32,12 +32,16 @@ namespace snapper
     using std::string;
 
 
+    typedef uint64_t qgroup_t;
+    const qgroup_t no_qgroup = 0;
+
     bool is_subvolume(const struct stat& stat);
 
     bool is_subvolume_read_only(int fd);
 
     void create_subvolume(int fddst, const string& name);
-    void create_snapshot(int fd, int fddst, const string& name, bool read_only);
+    void create_snapshot(int fd, int fddst, const string& name, bool read_only,
+			 qgroup_t qgroup);
     void delete_subvolume(int fd, const string& name);
 
     void set_default_id(int fd, unsigned long long id);
@@ -46,6 +50,9 @@ namespace snapper
     string get_subvolume(int fd, unsigned long long id);
     unsigned long long get_id(int fd);
 
+    qgroup_t make_qgroup(uint64_t level, uint64_t id);
+    qgroup_t make_qgroup(const string& str);
+
 }
 
 
