@@ -105,7 +105,8 @@ namespace snapper
 #ifdef ENABLE_LVM
 		&Lvm::create,
 #endif
-	NULL };
+		NULL
+	};
 
 	for (const func_t* func = funcs; *func != NULL; ++func)
 	{
@@ -119,6 +120,20 @@ namespace snapper
     }
 
 
+    Filesystem*
+    Filesystem::create(const ConfigInfo& config_info)
+    {
+	string fstype = "btrfs";
+	config_info.getValue(KEY_FSTYPE, fstype);
+
+	Filesystem* fs = create(fstype, config_info.getSubvolume());
+
+	fs->evalConfigInfo(config_info);
+
+	return fs;
+    }
+
+
     SDir
     Filesystem::openSubvolumeDir() const
     {
