@@ -91,9 +91,7 @@ namespace snapper
 	    throw ConfigNotFoundException();
 	}
 
-	string fstype = "btrfs";
-	config_info->getValue(KEY_FSTYPE, fstype);
-	filesystem = Filesystem::create(fstype, config_info->getSubvolume());
+	filesystem = Filesystem::create(*config_info);
 
 	bool sync_acl;
 	if (config_info->getValue(KEY_SYNC_ACL, sync_acl) && sync_acl == true)
@@ -405,7 +403,23 @@ namespace snapper
 	    throw CreateConfigFailedException("modifying config failed");
 	}
 
-	filesystem->createConfig(add_fstab);
+	try
+	{
+	    filesystem->createConfig(add_fstab);
+	}
+	catch (...)
+	{
+	    SysconfigFile sysconfig(SYSCONFIGFILE);
+	    vector<string> config_names;
+	    sysconfig.getValue("SNAPPER_CONFIGS", config_names);
+	    config_names.erase(remove(config_names.begin(), config_names.end(), config_name),
+			       config_names.end());
+	    sysconfig.setValue("SNAPPER_CONFIGS", config_names);
+
+	    SystemCmd cmd(RMBIN " " + quote(CONFIGSDIR "/" + config_name));
+
+	    throw;
+	}
 
 #ifdef ENABLE_ROLLBACK
 	if (subvolume == "/" && filesystem->fstype() == "btrfs" &&
@@ -714,4 +728,50 @@ namespace snapper
 	return !best_match.empty();
     }
 
+
+    const char*
+    Snapper::compileVersion()
+    {
+	return VERSION;
+    }
+
+
+    const char*
+    Snapper::compileFlags()
+    {
+	return
+
+#ifndef ENABLE_BTRFS
+	    "no-"
+#endif
+	    "btrfs,"
+
+#ifndef ENABLE_LVM
+	    "no-"
+#endif
+	    "lvm,"
+
+#ifndef ENABLE_EXT4
+	    "no-"
+#endif
+	    "ext4,"
+
+#ifndef ENABLE_XATTRS
+	    "no-"
+#endif
+	    "xattrs,"
+
+#ifndef ENABLE_ROLLBACK
+	    "no-"
+#endif
+	    "rollback,"
+
+#ifndef ENABLE_BTRFS_QUOTA
+	    "no-"
+#endif
+	    "btrfs-quota"
+
+	    ;
+    }
+
 }
