@@ -1,7 +1,4 @@
 
-#include <stdlib.h>
-#include <iostream>
-
 #include "common.h"
 
 using namespace std;
