@@ -1,10 +1,7 @@
 
-#include <stdlib.h>
 #include <string.h>
 #include <sys/xattr.h>
 
-#include <iostream>
-
 #include "xattrs_utils.h"
 #include "common.h"
 
